<?php

namespace Litecms\Adverts\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Adverts\Models\Advert;

class AdvertPolicy
{

    /**
     * Determine if the given user can view the advert.
     *
     * @param UserPolicy $user
     * @param Advert $advert
     *
     * @return bool
     */
    public function view(UserPolicy $user, Advert $advert)
    {
        if ($user->canDo('adverts.advert.view') && $user->isAdmin()) {
            return true;
        }

        return $advert->user_id == user_id() && $advert->user_type == user_type();
    }

    /**
     * Determine if the given user can create a advert.
     *
     * @param UserPolicy $user
     * @param Advert $advert
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('adverts.advert.create');
    }

    /**
     * Determine if the given user can update the given advert.
     *
     * @param UserPolicy $user
     * @param Advert $advert
     *
     * @return bool
     */
    public function update(UserPolicy $user, Advert $advert)
    {
        if ($user->canDo('adverts.advert.edit') && $user->isAdmin()) {
            return true;
        }

        return $advert->user_id == user_id() && $advert->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given advert.
     *
     * @param UserPolicy $user
     * @param Advert $advert
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Advert $advert)
    {
        return $advert->user_id == user_id() && $advert->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given advert.
     *
     * @param UserPolicy $user
     * @param Advert $advert
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Advert $advert)
    {
        if ($user->canDo('adverts.advert.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given advert.
     *
     * @param UserPolicy $user
     * @param Advert $advert
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Advert $advert)
    {
        if ($user->canDo('adverts.advert.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
